@@ -18,6 +18,7 @@ except ImportError:
     sys.exit(1)
 
 from setuptools.command import test
+from setuptools.command import egg_info
 from setuptools.command import build_py
 from distutils.sysconfig import get_config_var, get_config_vars
 
@@ -38,6 +39,15 @@ class oc_build_py (build_py.build_py):
 from pkg_resources import working_set, normalize_path, add_activation_listener, require
 from distutils.errors import DistutilsPlatformError, DistutilsError
 
+class oc_egg_info (egg_info.egg_info):
+    def run(self):
+        egg_info.egg_info.run(self)
+
+        path = os.path.join(self.egg_info, 'PKG-INFO')
+        with open(path, 'a+') as fp:
+            fp.write('Project-URL: Documentation, https://pyobjc.readthedocs.io/en/latest/\n')
+            fp.write('Project-URL: Issue tracker, https://bitbucket.org/ronaldoussoren/pyobjc/issues?status=new&status=open\n')
+
 class oc_test (test.test):
     description = "run test suite"
     user_options = [
@@ -178,6 +188,7 @@ Programming Language :: Python :: 2.7
 Programming Language :: Python :: 3
 Programming Language :: Python :: 3.4
 Programming Language :: Python :: 3.5
+Programming Language :: Python :: 3.6
 Programming Language :: Python :: Implementation :: CPython
 Programming Language :: Objective C
 Topic :: Software Development :: Libraries :: Python Modules
@@ -374,13 +385,13 @@ def Extension(*args, **kwds):
     if os_level is None:
         os_level = get_os_level()
 
-    cflags =  ["-DPyObjC_BUILD_RELEASE=%02d%02d"%(tuple(map(int, os_level.split('.'))))]
+    cflags =  []
     ldflags = []
     if 'clang' in get_config_var('CC'):
         cflags.append('-Wno-deprecated-declarations')
 
     CFLAGS = get_config_var('CFLAGS')
-    if '-isysroot' not in CFLAGS and os.path.exists('/usr/include/stdio.h'):
+    if '-isysroot' not in CFLAGS: # and os.path.exists('/usr/include/stdio.h'):
         # We're likely on a system with de Xcode Command Line Tools.
         # Explicitly use the most recent problems to avoid compile problems.
         data = os.popen('xcodebuild -version -sdk macosx Path').read()
@@ -388,6 +399,10 @@ def Extension(*args, **kwds):
         if data:
             cflags.append('-isysroot')
             cflags.append(data)
+            cflags.append("-DPyObjC_BUILD_RELEASE=%02d%02d"%(tuple(map(int, os.path.basename(data)[6:-4].split('.')))))
+
+    else:
+            cflags.append("-DPyObjC_BUILD_RELEASE=%02d%02d"%(tuple(map(int, os_level.split('.')))))
 
 
     if os_level == '10.4':
@@ -437,7 +452,14 @@ def setup(
     else:
         cmdclass = cmdclass.copy()
 
-    if not os_compatible:
+    if os_compatible or ('bdist_wheel' in sys.argv and 'ext_modules' not in k):
+        cmdclass['build_ext'] = pyobjc_build_ext
+        cmdclass['egg_info'] = oc_egg_info
+        cmdclass['install_lib'] = pyobjc_install_lib
+        cmdclass['test'] = oc_test
+        cmdclass['build_py'] = oc_build_py
+
+    else:
         if min_os_level != None:
             if max_os_level != None:
                 msg = "This distribution is only supported on MacOSX versions %s upto and including %s"%(
@@ -468,14 +490,9 @@ def setup(
         cmdclass['install_lib'] = create_command_subclass(pyobjc_install_lib)
         cmdclass['develop'] = create_command_subclass(develop.develop)
         cmdclass['build_py'] = create_command_subclass(oc_build_py)
-    else:
-        cmdclass['build_ext'] = pyobjc_build_ext
-        cmdclass['install_lib'] = pyobjc_install_lib
-        cmdclass['test'] = oc_test
-        cmdclass['build_py'] = oc_build_py
 
     if 'ext_modules' not in k:
-        # No extension modules, can bulid universal wheel
+        # No extension modules, can build universal wheel
         k['options'] = {
             'bdist_wheel': {
                 'universal': 1,
@@ -499,11 +516,20 @@ def setup(
             if len(k['setup_requires']) == 1 and k['setup_requires'][0].startswith('pyobjc-core'):
                 del k['setup_requires']
 
+    if 'long_description' in k:
+        k['long_description'] += "\n\nProject links\n"
+        k['long_description'] += "-------------\n"
+        k['long_description'] += "\n"
+        k['long_description'] += "* `Documetation <https://pyobjc.readthedocs.io/en/latest/>`_\n\n"
+        k['long_description'] += "* `Issue Tracker <https://bitbucket.org/ronaldoussoren/pyobjc/issues?status=new&status=open>`_\n\n"
+        k['long_description'] += "* `Repository <https://bitbucket.org/ronaldoussoren/pyobjc/>`_\n\n"
+        k['long_description_content_type'] = 'text/x-rst; charset=UTF-8'
+
     _setup(
         cmdclass=cmdclass,
         author='Ronald Oussoren',
         author_email='pyobjc-dev@lists.sourceforge.net',
-        url='http://pyobjc.sourceforge.net',
+        url='https://bitbucket.org/ronaldoussoren/pyobjc',
         platforms = [ plat_name ],
         package_dir = { '': 'Lib', 'PyObjCTest': 'PyObjCTest' },
         dependency_links = [],
